[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Stocks API for Digital Portals client library for Python

[![API Version](https://img.shields.io/badge/api-v2-blue)](https://endpointreference.mdgms.com)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.StocksAPIforDigitalPortals/0.10.20)](https://pypi.org/project/fds.sdk.StocksAPIforDigitalPortals/v/0.10.20)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

The Stocks API features a screener to search for equity instruments based on stock-specific parameters.

Parameters for up to three fiscal years might now be used in one request; data is available for the ten most recent completed fiscal years.
Estimates are available for the current and two consecutive fiscal years. Search criteria also include benchmark-related attributes
(beta, correlation, outperformance), and ESG parameters, based on FactSet’s Truvalue ESG scores.

A separate endpoint returns the possible values and value ranges for the parameters that the endpoint /stock/notation/screener/search accepts
Application developers can request the values and value ranges only for a restricted set of notations that match predefined parameters. This
functionality may be used to pre-fill the values and value ranges of the parameters of the /stock/notation/screener/search endpoint so that
performing a search always leads to a non-empty set of notations.

The endpoint /stock/notation/ranking/intraday/list ranks stocks notations using intraday figures, for example to build a gainers/losers list. 

Additional endpoints include end-of-day benchmark key figures, and selected fundamentals (as of end of fiscal year and with daily updates).

This API is fully integrated with the corresponding [Quotes API](https://developer.factset.com/api-catalog/quotes-api-digital-portals), allowing
access to detailed price and performance information of instruments, as well as basic security identifier cross-reference. For direct access
to price histories, please refer to the [Time Series API for Digital Portals](https://developer.factset.com/api-catalog/time-series-api-digital-portals).

Similar criteria based screener APIs exist for fixed income instruments and securitized derivatives: See the
[Bonds API](https://developer.factset.com/api-catalog/bonds-api-digital-portals) and the
[Securitized Derivatives API](https://developer.factset.com/api-catalog/securitized-derivatives-api-digital-portals) for details.

See also the recipe [\"Enrich Your Digital Portal with Flexible Equity Screening\"](https://developer.factset.com/recipe-catalog/enrich-your-digital-portal-flexible-equity-screening).


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2
- SDK version: 0.10.20
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.StocksAPIforDigitalPortals==0.10.20
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.StocksAPIforDigitalPortals==0.10.20
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.StocksAPIforDigitalPortals
from fds.sdk.StocksAPIforDigitalPortals.api import company_api
from fds.sdk.StocksAPIforDigitalPortals.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.StocksAPIforDigitalPortals.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.StocksAPIforDigitalPortals.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.StocksAPIforDigitalPortals.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = company_api.CompanyApi(api_client)
    id = "id_example" # str | 
    attributes = [
        "_attributes_example",
    ] # [str] | Limit the attributes returned in the response to the specified set. (optional)
    language = "_language_example" # str |  (optional)

    try:
        # List of boards for a company, with their officers.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_company_board_list_by_instrument(id, attributes=attributes, language=language)

        pprint(api_response)
    except fds.sdk.StocksAPIforDigitalPortals.ApiException as e:
        print("Exception when calling CompanyApi->get_company_board_list_by_instrument: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # List of boards for a company, with their officers.
    #     api_response, http_status_code, response_headers = api_instance.get_company_board_list_by_instrument_with_http_info(id, attributes=attributes, language=language)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.StocksAPIforDigitalPortals.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_board_list_by_instrument: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # List of boards for a company, with their officers.
    #     async_result = api_instance.get_company_board_list_by_instrument_async(id, attributes=attributes, language=language)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.StocksAPIforDigitalPortals.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_board_list_by_instrument: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # List of boards for a company, with their officers.
    #     async_result = api_instance.get_company_board_list_by_instrument_with_http_info_async(id, attributes=attributes, language=language)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.StocksAPIforDigitalPortals.ApiException as e:
    #     print("Exception when calling CompanyApi->get_company_board_list_by_instrument: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.StocksAPIforDigitalPortals

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.StocksAPIforDigitalPortals.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.StocksAPIforDigitalPortals

configuration = fds.sdk.StocksAPIforDigitalPortals.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.StocksAPIforDigitalPortals

configuration = fds.sdk.StocksAPIforDigitalPortals.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.StocksAPIforDigitalPortals

configuration = fds.sdk.StocksAPIforDigitalPortals.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/wealth/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CompanyApi* | [**get_company_board_list_by_instrument**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CompanyApi.md#get_company_board_list_by_instrument) | **GET** /company/board/listByInstrument | List of boards for a company, with their officers.
*CompanyApi* | [**get_company_board_officer_function_delivery_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CompanyApi.md#get_company_board_officer_function_delivery_list) | **GET** /company/board/officer/function/delivery/list | List of officer functions as provided by a delivery.
*CompanyApi* | [**get_company_board_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CompanyApi.md#get_company_board_type_list) | **GET** /company/board/type/list | List of company board types.
*CompanyApi* | [**post_company_estimates_list_by_instrument**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CompanyApi.md#post_company_estimates_list_by_instrument) | **POST** /company/estimates/listByInstrument | Estimates for selected figures for a stock.
*CompanyApi* | [**post_company_key_items_current_get_by_instrument**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CompanyApi.md#post_company_key_items_current_get_by_instrument) | **POST** /company/keyItems/current/getByInstrument | Fundamentals for a stock with potentially daily updates.
*CompanyApi* | [**post_company_key_items_fiscal_year_list_by_instrument**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CompanyApi.md#post_company_key_items_fiscal_year_list_by_instrument) | **POST** /company/keyItems/fiscalYear/listByInstrument | Selected fundamentals for a stock with values as of the end of a fiscal year.
*StockApi* | [**get_stock_composite_profile_get_by_notation**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_composite_profile_get_by_notation) | **GET** /stock/composite/profile/getByNotation | Provides key elements of a stock profile together with the profile of the issuing company.
*StockApi* | [**get_stock_dividend_type_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_dividend_type_list) | **GET** /stock/dividend/type/list | List of dividend types.
*StockApi* | [**get_stock_notation_key_figures_benchmark_month_1_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_notation_key_figures_benchmark_month_1_get) | **GET** /stock/notation/keyFigures/benchmark/month/1/get | End-of-day (EOD) benchmark key figures of a stock for the time range of one month.
*StockApi* | [**get_stock_notation_key_figures_benchmark_month_3_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_notation_key_figures_benchmark_month_3_get) | **GET** /stock/notation/keyFigures/benchmark/month/3/get | End-of-day (EOD) benchmark key figures of a stock for the time range of three months.
*StockApi* | [**get_stock_notation_key_figures_benchmark_month_6_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_notation_key_figures_benchmark_month_6_get) | **GET** /stock/notation/keyFigures/benchmark/month/6/get | End-of-day (EOD) benchmark key figures of a stock for the time range of six months.
*StockApi* | [**get_stock_notation_key_figures_benchmark_week_1_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_notation_key_figures_benchmark_week_1_get) | **GET** /stock/notation/keyFigures/benchmark/week/1/get | End-of-day (EOD) benchmark key figures of a stock for the time range of one week.
*StockApi* | [**get_stock_notation_key_figures_benchmark_year_1_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_notation_key_figures_benchmark_year_1_get) | **GET** /stock/notation/keyFigures/benchmark/year/1/get | End-of-day (EOD) benchmark key figures of a stock for the time range of one year.
*StockApi* | [**get_stock_notation_key_figures_benchmark_year_3_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_notation_key_figures_benchmark_year_3_get) | **GET** /stock/notation/keyFigures/benchmark/year/3/get | End-of-day (EOD) benchmark key figures of a stock for the time range of three years.
*StockApi* | [**get_stock_notation_key_figures_benchmark_year_5_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_notation_key_figures_benchmark_year_5_get) | **GET** /stock/notation/keyFigures/benchmark/year/5/get | End-of-day (EOD) benchmark key figures of a stock for the time range of five years.
*StockApi* | [**get_stock_owner_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_owner_list) | **GET** /stock/owner/list | List of owners for a specific type of a company&#39;s shares.
*StockApi* | [**get_stock_recommendation_aggregate_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_recommendation_aggregate_get) | **GET** /stock/recommendation/aggregate/get | Target price and aggregated recommendations for a stock.
*StockApi* | [**get_stock_recommendation_aggregate_history_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#get_stock_recommendation_aggregate_history_list) | **GET** /stock/recommendation/aggregate/history/list | Current and historical trade recommendations and target prices for a stock.
*StockApi* | [**post_stock_dividend_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#post_stock_dividend_list) | **POST** /stock/dividend/list | List of dividends for a stock.
*StockApi* | [**post_stock_notation_ranking_intraday_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#post_stock_notation_ranking_intraday_list) | **POST** /stock/notation/ranking/intraday/list | Ranking of stocks&#39; notations using intraday figures.
*StockApi* | [**post_stock_notation_screener_search**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#post_stock_notation_screener_search) | **POST** /stock/notation/screener/search | Screener for stocks&#39; notations based on stock-specific parameters.
*StockApi* | [**post_stock_notation_screener_value_ranges_get**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StockApi.md#post_stock_notation_screener_value_ranges_get) | **POST** /stock/notation/screener/valueRanges/get | Possible values and value ranges for the parameters used in the endpoint &#x60;/stock/notation/screener/search&#x60;.


## Documentation For Models

 - [AttributesMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/AttributesMember.md)
 - [CursorBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CursorBasedPaginationOutputObject.md)
 - [CursorBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/CursorBasedPaginationOutputObjectWithoutTotal.md)
 - [ErrorMetaObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/ErrorMetaObject.md)
 - [ErrorObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/ErrorObject.md)
 - [InlineResponse200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200.md)
 - [InlineResponse2001](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001.md)
 - [InlineResponse20010](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010.md)
 - [InlineResponse20010Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010Data.md)
 - [InlineResponse20010DataCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010DataCurrency.md)
 - [InlineResponse20010DataDates](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010DataDates.md)
 - [InlineResponse20010DataDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010DataDividends.md)
 - [InlineResponse20010DataGross](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010DataGross.md)
 - [InlineResponse20010DataOccurrence](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010DataOccurrence.md)
 - [InlineResponse20010DataOccurrenceFrequency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010DataOccurrenceFrequency.md)
 - [InlineResponse20010DataType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20010DataType.md)
 - [InlineResponse20011](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20011.md)
 - [InlineResponse20011Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20011Data.md)
 - [InlineResponse20012](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20012.md)
 - [InlineResponse20012Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20012Data.md)
 - [InlineResponse20012DataBenchmarks](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20012DataBenchmarks.md)
 - [InlineResponse20012DataNotation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20012DataNotation.md)
 - [InlineResponse20012DataNotationInstrument](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20012DataNotationInstrument.md)
 - [InlineResponse20012DataStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20012DataStatus.md)
 - [InlineResponse20013](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013.md)
 - [InlineResponse20013Accumulated](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Accumulated.md)
 - [InlineResponse20013Currency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Currency.md)
 - [InlineResponse20013Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Data.md)
 - [InlineResponse20013Fsym](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Fsym.md)
 - [InlineResponse20013FsymListing](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013FsymListing.md)
 - [InlineResponse20013FsymRegional](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013FsymRegional.md)
 - [InlineResponse20013Instrument](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Instrument.md)
 - [InlineResponse20013InstrumentIndustryClassification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013InstrumentIndustryClassification.md)
 - [InlineResponse20013InstrumentIndustryClassificationRbics](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013InstrumentIndustryClassificationRbics.md)
 - [InlineResponse20013Market](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Market.md)
 - [InlineResponse20013Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Meta.md)
 - [InlineResponse20013Trade](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013Trade.md)
 - [InlineResponse20013TradePerformance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20013TradePerformance.md)
 - [InlineResponse20014](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014.md)
 - [InlineResponse20014Benchmark](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Benchmark.md)
 - [InlineResponse20014BenchmarkBeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014BenchmarkBeta.md)
 - [InlineResponse20014BenchmarkCorrelation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014BenchmarkCorrelation.md)
 - [InlineResponse20014BenchmarkIndex](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014BenchmarkIndex.md)
 - [InlineResponse20014BenchmarkOutperformance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014BenchmarkOutperformance.md)
 - [InlineResponse20014Compliance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Compliance.md)
 - [InlineResponse20014ComplianceFrance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ComplianceFrance.md)
 - [InlineResponse20014CurrentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFigures.md)
 - [InlineResponse20014CurrentKeyFiguresCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFiguresCompany.md)
 - [InlineResponse20014CurrentKeyFiguresCompanyCurrencyDependent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFiguresCompanyCurrencyDependent.md)
 - [InlineResponse20014CurrentKeyFiguresCompanyCurrencyDependentPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFiguresCompanyCurrencyDependentPerShare.md)
 - [InlineResponse20014CurrentKeyFiguresShareInstrument](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFiguresShareInstrument.md)
 - [InlineResponse20014CurrentKeyFiguresShareInstrumentCurrencyDependent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFiguresShareInstrumentCurrencyDependent.md)
 - [InlineResponse20014CurrentKeyFiguresShareInstrumentCurrencyDependentPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFiguresShareInstrumentCurrencyDependentPerShare.md)
 - [InlineResponse20014CurrentKeyFiguresShareInstrumentRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014CurrentKeyFiguresShareInstrumentRatios.md)
 - [InlineResponse20014Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Data.md)
 - [InlineResponse20014Esg](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Esg.md)
 - [InlineResponse20014EsgTruvalueLabs](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EsgTruvalueLabs.md)
 - [InlineResponse20014EsgTruvalueLabsSasb](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EsgTruvalueLabsSasb.md)
 - [InlineResponse20014EsgTruvalueLabsSasbAllCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EsgTruvalueLabsSasbAllCategories.md)
 - [InlineResponse20014EsgTruvalueLabsSasbMateriality](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EsgTruvalueLabsSasbMateriality.md)
 - [InlineResponse20014EsgTruvalueLabsSdg](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EsgTruvalueLabsSdg.md)
 - [InlineResponse20014EsgTruvalueLabsSdgImpact](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EsgTruvalueLabsSdgImpact.md)
 - [InlineResponse20014Estimates](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Estimates.md)
 - [InlineResponse20014EstimatesFirstFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYear.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimates](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimates.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesCurrency.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesEbit.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesEbitda.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShare.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareCashFlow.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareDividends.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareEarnings.md)
 - [InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareSales.md)
 - [InlineResponse20014EstimatesFirstFiscalYearFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearFiscalYear.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatios.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosDividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosDividendYield.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosEnterpriseValueEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosEnterpriseValueEbit.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosEnterpriseValueEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosEnterpriseValueEbitda.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosEnterpriseValueSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosEnterpriseValueSales.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosPriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosPriceBookValue.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosPriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosPriceCashFlow.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosPriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosPriceEarnings.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosPriceEarningsGrowth](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosPriceEarningsGrowth.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosPriceFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosPriceFreeCashFlow.md)
 - [InlineResponse20014EstimatesFirstFiscalYearRatiosPriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearRatiosPriceSales.md)
 - [InlineResponse20014EstimatesFirstFiscalYearReturnOnAssets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearReturnOnAssets.md)
 - [InlineResponse20014EstimatesFirstFiscalYearReturnOnEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesFirstFiscalYearReturnOnEquity.md)
 - [InlineResponse20014EstimatesSecondFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesSecondFiscalYear.md)
 - [InlineResponse20014EstimatesThirdFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014EstimatesThirdFiscalYear.md)
 - [InlineResponse20014Instrument](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Instrument.md)
 - [InlineResponse20014InstrumentCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentCompany.md)
 - [InlineResponse20014InstrumentCompanyCountry](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentCompanyCountry.md)
 - [InlineResponse20014InstrumentIndustryClassification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassification.md)
 - [InlineResponse20014InstrumentIndustryClassificationRbics](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassificationRbics.md)
 - [InlineResponse20014InstrumentIndustryClassificationRbicsLevel1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassificationRbicsLevel1.md)
 - [InlineResponse20014InstrumentIndustryClassificationRbicsLevel2](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassificationRbicsLevel2.md)
 - [InlineResponse20014InstrumentIndustryClassificationRbicsLevel3](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassificationRbicsLevel3.md)
 - [InlineResponse20014InstrumentIndustryClassificationRbicsLevel4](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassificationRbicsLevel4.md)
 - [InlineResponse20014InstrumentIndustryClassificationRbicsLevel5](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassificationRbicsLevel5.md)
 - [InlineResponse20014InstrumentIndustryClassificationRbicsLevel6](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentIndustryClassificationRbicsLevel6.md)
 - [InlineResponse20014InstrumentNsin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014InstrumentNsin.md)
 - [InlineResponse20014Market](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Market.md)
 - [InlineResponse20014Nsin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Nsin.md)
 - [InlineResponse20014Performance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Performance.md)
 - [InlineResponse20014PerformanceEndOfDay](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014PerformanceEndOfDay.md)
 - [InlineResponse20014Recommendation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Recommendation.md)
 - [InlineResponse20014RecommendationConsensus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014RecommendationConsensus.md)
 - [InlineResponse20014RecommendationConsensusChange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014RecommendationConsensusChange.md)
 - [InlineResponse20014RecommendationCounts](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014RecommendationCounts.md)
 - [InlineResponse20014ReportedKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFigures.md)
 - [InlineResponse20014ReportedKeyFiguresFirstFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresFirstFiscalYear.md)
 - [InlineResponse20014ReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFigures.md)
 - [InlineResponse20014ReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresCurrency.md)
 - [InlineResponse20014ReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShare.md)
 - [InlineResponse20014ReportedKeyFiguresFirstFiscalYearFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresFirstFiscalYearFiscalYear.md)
 - [InlineResponse20014ReportedKeyFiguresFirstFiscalYearRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresFirstFiscalYearRatios.md)
 - [InlineResponse20014ReportedKeyFiguresSecondFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresSecondFiscalYear.md)
 - [InlineResponse20014ReportedKeyFiguresThirdFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ReportedKeyFiguresThirdFiscalYear.md)
 - [InlineResponse20014RsiWilder](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014RsiWilder.md)
 - [InlineResponse20014SimpleMovingAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014SimpleMovingAverage.md)
 - [InlineResponse20014SimpleMovingAverageTradingDaysSinceCrossover](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014SimpleMovingAverageTradingDaysSinceCrossover.md)
 - [InlineResponse20014SimpleMovingAverageTradingDaysSinceCrossoverSma20vs50](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014SimpleMovingAverageTradingDaysSinceCrossoverSma20vs50.md)
 - [InlineResponse20014SimpleMovingAverageTradingDaysSinceCrossoverSma50vs200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014SimpleMovingAverageTradingDaysSinceCrossoverSma50vs200.md)
 - [InlineResponse20014TradingValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014TradingValue.md)
 - [InlineResponse20014TradingValueAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014TradingValueAverage.md)
 - [InlineResponse20014ValueUnit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014ValueUnit.md)
 - [InlineResponse20014Volatility](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20014Volatility.md)
 - [InlineResponse20015](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015.md)
 - [InlineResponse20015Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015Data.md)
 - [InlineResponse20015DataCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataCategories.md)
 - [InlineResponse20015DataCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataCompany.md)
 - [InlineResponse20015DataCompanyCountry](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataCompanyCountry.md)
 - [InlineResponse20015DataCompliance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataCompliance.md)
 - [InlineResponse20015DataComplianceFrance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataComplianceFrance.md)
 - [InlineResponse20015DataEstimates](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimates.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYear.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimates](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimates.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesCurrency.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesEbit.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesEbitMean](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesEbitMean.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesEbitda.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShare.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareCashFlow.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareDividends.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareEarnings.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearCurrencyDependentEstimatesPerShareSales.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearFiscalYear.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatios.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosDividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosDividendYield.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosDividendYieldMean](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosDividendYieldMean.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosEnterpriseValueEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosEnterpriseValueEbit.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosEnterpriseValueEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosEnterpriseValueEbitda.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosEnterpriseValueSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosEnterpriseValueSales.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceBookValue.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceCashFlow.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceEarnings.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceEarningsGrowth](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceEarningsGrowth.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceFreeCashFlow.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearRatiosPriceSales.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearReturnOnAssets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearReturnOnAssets.md)
 - [InlineResponse20015DataEstimatesFirstFiscalYearReturnOnEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesFirstFiscalYearReturnOnEquity.md)
 - [InlineResponse20015DataEstimatesSecondFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesSecondFiscalYear.md)
 - [InlineResponse20015DataEstimatesThirdFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataEstimatesThirdFiscalYear.md)
 - [InlineResponse20015DataIndustryClassification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataIndustryClassification.md)
 - [InlineResponse20015DataLevel](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataLevel.md)
 - [InlineResponse20015DataMarket](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataMarket.md)
 - [InlineResponse20015DataParent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataParent.md)
 - [InlineResponse20015DataPerformance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformance.md)
 - [InlineResponse20015DataPerformanceEndOfDay](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDay.md)
 - [InlineResponse20015DataPerformanceEndOfDayDay1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayDay1.md)
 - [InlineResponse20015DataPerformanceEndOfDayMonth1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayMonth1.md)
 - [InlineResponse20015DataPerformanceEndOfDayMonths3](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayMonths3.md)
 - [InlineResponse20015DataPerformanceEndOfDayMonths6](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayMonths6.md)
 - [InlineResponse20015DataPerformanceEndOfDayWeek1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayWeek1.md)
 - [InlineResponse20015DataPerformanceEndOfDayYear1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayYear1.md)
 - [InlineResponse20015DataPerformanceEndOfDayYearToDate](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayYearToDate.md)
 - [InlineResponse20015DataPerformanceEndOfDayYears3](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayYears3.md)
 - [InlineResponse20015DataPerformanceEndOfDayYears5](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceEndOfDayYears5.md)
 - [InlineResponse20015DataPerformanceIntraday](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataPerformanceIntraday.md)
 - [InlineResponse20015DataRecommendation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataRecommendation.md)
 - [InlineResponse20015DataRecommendationConsensus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataRecommendationConsensus.md)
 - [InlineResponse20015DataRecommendationCounts](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataRecommendationCounts.md)
 - [InlineResponse20015DataRecommendationCountsTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataRecommendationCountsTotal.md)
 - [InlineResponse20015DataReportedKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFigures.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYear.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFigures.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresCurrency.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresEbit.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresEbitda.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresMarketCapitalization](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresMarketCapitalization.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShare.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareBookValue.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareCashFlow.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareDividends.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareRecurringEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareRecurringEarnings.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearCurrencyDependentKeyFiguresPerShareSales.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearEbitMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearEbitMargin.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearEbitdaMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearEbitdaMargin.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearGrossIncomeMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearGrossIncomeMargin.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearNetIncomeMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearNetIncomeMargin.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearOperatingMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearOperatingMargin.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatios.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosDebtEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosDebtEquity.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosDividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosDividendYield.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosEnterpriseValueEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosEnterpriseValueEbit.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosEnterpriseValueEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosEnterpriseValueEbitda.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosEnterpriseValueSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosEnterpriseValueSales.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceBookValue.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceCashFlow.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceEarnings.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceFreeCashFlow.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearRatiosPriceSales.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearReturnOnAssets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearReturnOnAssets.md)
 - [InlineResponse20015DataReportedKeyFiguresFirstFiscalYearReturnOnEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresFirstFiscalYearReturnOnEquity.md)
 - [InlineResponse20015DataReportedKeyFiguresSecondFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresSecondFiscalYear.md)
 - [InlineResponse20015DataReportedKeyFiguresThirdFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataReportedKeyFiguresThirdFiscalYear.md)
 - [InlineResponse20015DataRsiWilder](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataRsiWilder.md)
 - [InlineResponse20015DataRsiWilderDays14](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataRsiWilderDays14.md)
 - [InlineResponse20015DataSimpleMovingAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverage.md)
 - [InlineResponse20015DataSimpleMovingAverageDays20](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageDays20.md)
 - [InlineResponse20015DataSimpleMovingAverageDays200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageDays200.md)
 - [InlineResponse20015DataSimpleMovingAverageDays50](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageDays50.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossover](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossover.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50Down](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50Down.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50Up](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50Up.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50UpNumberDays](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50UpNumberDays.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200Down](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200Down.md)
 - [InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200Up](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200Up.md)
 - [InlineResponse20015DataStockType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataStockType.md)
 - [InlineResponse20015DataTradingValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataTradingValue.md)
 - [InlineResponse20015DataTradingValueAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataTradingValueAverage.md)
 - [InlineResponse20015DataTradingValueAverageDays30](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataTradingValueAverageDays30.md)
 - [InlineResponse20015DataTradingValueAverageDays5](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataTradingValueAverageDays5.md)
 - [InlineResponse20015DataValueUnit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataValueUnit.md)
 - [InlineResponse20015DataVolatility](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse20015DataVolatility.md)
 - [InlineResponse2001Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001Data.md)
 - [InlineResponse2001DataBalanceSheet](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheet.md)
 - [InlineResponse2001DataBalanceSheetCashAndDueFromBanks](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetCashAndDueFromBanks.md)
 - [InlineResponse2001DataBalanceSheetCashAndShortTermInvestments](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetCashAndShortTermInvestments.md)
 - [InlineResponse2001DataBalanceSheetNetDebt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetNetDebt.md)
 - [InlineResponse2001DataBalanceSheetTotalAssets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetTotalAssets.md)
 - [InlineResponse2001DataBalanceSheetTotalCash](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetTotalCash.md)
 - [InlineResponse2001DataBalanceSheetTotalDebt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetTotalDebt.md)
 - [InlineResponse2001DataBalanceSheetTotalDeposits](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetTotalDeposits.md)
 - [InlineResponse2001DataBalanceSheetTotalLiabilities](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetTotalLiabilities.md)
 - [InlineResponse2001DataBalanceSheetTotalLoans](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetTotalLoans.md)
 - [InlineResponse2001DataBalanceSheetTotalShareholdersEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataBalanceSheetTotalShareholdersEquity.md)
 - [InlineResponse2001DataCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataCashFlow.md)
 - [InlineResponse2001DataCashFlowCapitalExpenditures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataCashFlowCapitalExpenditures.md)
 - [InlineResponse2001DataCashFlowNetFinancingCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataCashFlowNetFinancingCashFlow.md)
 - [InlineResponse2001DataCashFlowNetInvestingCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataCashFlowNetInvestingCashFlow.md)
 - [InlineResponse2001DataCashFlowNetOperating](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataCashFlowNetOperating.md)
 - [InlineResponse2001DataCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataCompany.md)
 - [InlineResponse2001DataCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataCurrency.md)
 - [InlineResponse2001DataFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataFiscalYear.md)
 - [InlineResponse2001DataFiscalYearData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataFiscalYearData.md)
 - [InlineResponse2001DataIncomeStatement](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatement.md)
 - [InlineResponse2001DataIncomeStatementClaimLossExpense](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementClaimLossExpense.md)
 - [InlineResponse2001DataIncomeStatementEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementEbit.md)
 - [InlineResponse2001DataIncomeStatementEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementEbitda.md)
 - [InlineResponse2001DataIncomeStatementGrossIncome](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementGrossIncome.md)
 - [InlineResponse2001DataIncomeStatementInterestExpense](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementInterestExpense.md)
 - [InlineResponse2001DataIncomeStatementInterestIncome](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementInterestIncome.md)
 - [InlineResponse2001DataIncomeStatementLoanLossProvision](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementLoanLossProvision.md)
 - [InlineResponse2001DataIncomeStatementLongTermInsuranceReserves](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementLongTermInsuranceReserves.md)
 - [InlineResponse2001DataIncomeStatementNetIncome](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementNetIncome.md)
 - [InlineResponse2001DataIncomeStatementNetInterestIncome](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementNetInterestIncome.md)
 - [InlineResponse2001DataIncomeStatementNetInterestIncomeAfterLoanLossProvision](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementNetInterestIncomeAfterLoanLossProvision.md)
 - [InlineResponse2001DataIncomeStatementOperatingExpense](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementOperatingExpense.md)
 - [InlineResponse2001DataIncomeStatementOperatingIncome](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementOperatingIncome.md)
 - [InlineResponse2001DataIncomeStatementOperatingIncomeAfterInterestExpense](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementOperatingIncomeAfterInterestExpense.md)
 - [InlineResponse2001DataIncomeStatementSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataIncomeStatementSales.md)
 - [InlineResponse2001DataNsin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataNsin.md)
 - [InlineResponse2001DataPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShare.md)
 - [InlineResponse2001DataPerShareBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareBookValue.md)
 - [InlineResponse2001DataPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareCashFlow.md)
 - [InlineResponse2001DataPerShareDilutedEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareDilutedEarnings.md)
 - [InlineResponse2001DataPerShareDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareDividends.md)
 - [InlineResponse2001DataPerShareEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareEarnings.md)
 - [InlineResponse2001DataPerShareFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareFreeCashFlow.md)
 - [InlineResponse2001DataPerShareRecurringDilutedEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareRecurringDilutedEarnings.md)
 - [InlineResponse2001DataPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareSales.md)
 - [InlineResponse2001DataPerShareTangibleBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataPerShareTangibleBookValue.md)
 - [InlineResponse2001DataRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataRatios.md)
 - [InlineResponse2001DataSharesOutstanding](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataSharesOutstanding.md)
 - [InlineResponse2001DataSharesOutstandingAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataSharesOutstandingAverage.md)
 - [InlineResponse2001DataType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2001DataType.md)
 - [InlineResponse2002](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002.md)
 - [InlineResponse2002BalanceSheet](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002BalanceSheet.md)
 - [InlineResponse2002BalanceSheetNetDebt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002BalanceSheetNetDebt.md)
 - [InlineResponse2002BalanceSheetReturnOnAssets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002BalanceSheetReturnOnAssets.md)
 - [InlineResponse2002BalanceSheetReturnOnEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002BalanceSheetReturnOnEquity.md)
 - [InlineResponse2002Currency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002Currency.md)
 - [InlineResponse2002Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002Data.md)
 - [InlineResponse2002FiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002FiscalYear.md)
 - [InlineResponse2002IncomeStatement](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002IncomeStatement.md)
 - [InlineResponse2002IncomeStatementEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002IncomeStatementEbit.md)
 - [InlineResponse2002IncomeStatementEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002IncomeStatementEbitda.md)
 - [InlineResponse2002IncomeStatementSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002IncomeStatementSales.md)
 - [InlineResponse2002PerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002PerShare.md)
 - [InlineResponse2002PerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002PerShareCashFlow.md)
 - [InlineResponse2002PerShareDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002PerShareDividends.md)
 - [InlineResponse2002PerShareEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002PerShareEarnings.md)
 - [InlineResponse2002PerShareNetAssetValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002PerShareNetAssetValue.md)
 - [InlineResponse2002PerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002PerShareSales.md)
 - [InlineResponse2002Ratios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002Ratios.md)
 - [InlineResponse2002RatiosDividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosDividendYield.md)
 - [InlineResponse2002RatiosEnterpriseValueEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosEnterpriseValueEbit.md)
 - [InlineResponse2002RatiosEnterpriseValueEbita](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosEnterpriseValueEbita.md)
 - [InlineResponse2002RatiosEnterpriseValueEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosEnterpriseValueEbitda.md)
 - [InlineResponse2002RatiosEnterpriseValueFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosEnterpriseValueFreeCashFlow.md)
 - [InlineResponse2002RatiosEnterpriseValueSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosEnterpriseValueSales.md)
 - [InlineResponse2002RatiosPriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosPriceBookValue.md)
 - [InlineResponse2002RatiosPriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosPriceCashFlow.md)
 - [InlineResponse2002RatiosPriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosPriceEarnings.md)
 - [InlineResponse2002RatiosPriceEarningsGrowth](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosPriceEarningsGrowth.md)
 - [InlineResponse2002RatiosPriceFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosPriceFreeCashFlow.md)
 - [InlineResponse2002RatiosPriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2002RatiosPriceSales.md)
 - [InlineResponse2003](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2003.md)
 - [InlineResponse2003Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2003Data.md)
 - [InlineResponse2003DataRecommendation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2003DataRecommendation.md)
 - [InlineResponse2003DataRecommendationCounts](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2003DataRecommendationCounts.md)
 - [InlineResponse2003DataTargetPrice](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2003DataTargetPrice.md)
 - [InlineResponse2003DataTargetPriceCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2003DataTargetPriceCurrency.md)
 - [InlineResponse2004](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2004.md)
 - [InlineResponse2004Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2004Data.md)
 - [InlineResponse2004DataAggregatedRecommendations](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2004DataAggregatedRecommendations.md)
 - [InlineResponse2004DataRecommendation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2004DataRecommendation.md)
 - [InlineResponse2005](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2005.md)
 - [InlineResponse2005Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2005Data.md)
 - [InlineResponse2005Function](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2005Function.md)
 - [InlineResponse2005Officers](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2005Officers.md)
 - [InlineResponse2005Type](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2005Type.md)
 - [InlineResponse2006](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2006.md)
 - [InlineResponse2006Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2006Data.md)
 - [InlineResponse2006Functions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2006Functions.md)
 - [InlineResponse2007](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2007.md)
 - [InlineResponse2007Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2007Data.md)
 - [InlineResponse2008](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2008.md)
 - [InlineResponse2008Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2008Data.md)
 - [InlineResponse2008DataOwners](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2008DataOwners.md)
 - [InlineResponse2008DataOwnership](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2008DataOwnership.md)
 - [InlineResponse2008DataType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2008DataType.md)
 - [InlineResponse2009](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2009.md)
 - [InlineResponse2009Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse2009Data.md)
 - [InlineResponse200Data](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200Data.md)
 - [InlineResponse200DataCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompany.md)
 - [InlineResponse200DataCompanyCountry](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyCountry.md)
 - [InlineResponse200DataCompanyKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFigures.md)
 - [InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFigures.md)
 - [InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresMarketCapitalizationSharesOutstanding](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresMarketCapitalizationSharesOutstanding.md)
 - [InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShare.md)
 - [InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareBookValue.md)
 - [InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareCashFlow.md)
 - [InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareEarnings.md)
 - [InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresCurrencyDependentKeyFiguresPerShareSales.md)
 - [InlineResponse200DataCompanyKeyFiguresFreeFloat](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresFreeFloat.md)
 - [InlineResponse200DataCompanyKeyFiguresSharesOutstanding](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataCompanyKeyFiguresSharesOutstanding.md)
 - [InlineResponse200DataFsym](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataFsym.md)
 - [InlineResponse200DataFsymSecurity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataFsymSecurity.md)
 - [InlineResponse200DataNsin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataNsin.md)
 - [InlineResponse200DataShareInstrumentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFigures.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresCurrencyDependentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresCurrencyDependentKeyFigures.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresCurrencyDependentKeyFiguresPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresCurrencyDependentKeyFiguresPerShare.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresCurrencyDependentKeyFiguresPerShareDividend](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresCurrencyDependentKeyFiguresPerShareDividend.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresRatios.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresRatiosDividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresRatiosDividendYield.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresRatiosEarningsYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresRatiosEarningsYield.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceBookValue.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceCashFlow.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceEarnings.md)
 - [InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200DataShareInstrumentKeyFiguresRatiosPriceSales.md)
 - [InlineResponse200Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/InlineResponse200Meta.md)
 - [LanguageMember](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/LanguageMember.md)
 - [OffsetBasedPaginationOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/OffsetBasedPaginationOutputObject.md)
 - [OffsetBasedPaginationOutputObjectWithoutTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/OffsetBasedPaginationOutputObjectWithoutTotal.md)
 - [PartialOutputObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PartialOutputObject.md)
 - [PostCompanyEstimatesListByInstrumentRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyEstimatesListByInstrumentRequest.md)
 - [PostCompanyEstimatesListByInstrumentRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyEstimatesListByInstrumentRequestData.md)
 - [PostCompanyEstimatesListByInstrumentRequestDataCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyEstimatesListByInstrumentRequestDataCurrency.md)
 - [PostCompanyEstimatesListByInstrumentRequestDataFiscalYears](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyEstimatesListByInstrumentRequestDataFiscalYears.md)
 - [PostCompanyEstimatesListByInstrumentRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyEstimatesListByInstrumentRequestMeta.md)
 - [PostCompanyKeyItemsCurrentGetByInstrumentRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsCurrentGetByInstrumentRequest.md)
 - [PostCompanyKeyItemsCurrentGetByInstrumentRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsCurrentGetByInstrumentRequestData.md)
 - [PostCompanyKeyItemsCurrentGetByInstrumentRequestDataCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsCurrentGetByInstrumentRequestDataCurrency.md)
 - [PostCompanyKeyItemsCurrentGetByInstrumentRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsCurrentGetByInstrumentRequestMeta.md)
 - [PostCompanyKeyItemsFiscalYearListByInstrumentRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsFiscalYearListByInstrumentRequest.md)
 - [PostCompanyKeyItemsFiscalYearListByInstrumentRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsFiscalYearListByInstrumentRequestData.md)
 - [PostCompanyKeyItemsFiscalYearListByInstrumentRequestDataCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsFiscalYearListByInstrumentRequestDataCurrency.md)
 - [PostCompanyKeyItemsFiscalYearListByInstrumentRequestDataFiscalYears](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostCompanyKeyItemsFiscalYearListByInstrumentRequestDataFiscalYears.md)
 - [PostStockDividendListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockDividendListRequest.md)
 - [PostStockDividendListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockDividendListRequestData.md)
 - [PostStockDividendListRequestDataFilter](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockDividendListRequestDataFilter.md)
 - [PostStockDividendListRequestDataFilterPeriod](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockDividendListRequestDataFilterPeriod.md)
 - [PostStockDividendListRequestDataFilterType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockDividendListRequestDataFilterType.md)
 - [PostStockDividendListRequestDataIdentifier](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockDividendListRequestDataIdentifier.md)
 - [PostStockDividendListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockDividendListRequestMeta.md)
 - [PostStockNotationRankingIntradayListRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequest.md)
 - [PostStockNotationRankingIntradayListRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestData.md)
 - [PostStockNotationRankingIntradayListRequestDataCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataCompany.md)
 - [PostStockNotationRankingIntradayListRequestDataCompanyCountry](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataCompanyCountry.md)
 - [PostStockNotationRankingIntradayListRequestDataCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataCurrency.md)
 - [PostStockNotationRankingIntradayListRequestDataIndexMembership](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataIndexMembership.md)
 - [PostStockNotationRankingIntradayListRequestDataIndustryClassification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataIndustryClassification.md)
 - [PostStockNotationRankingIntradayListRequestDataInstrumentRestrictionList](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataInstrumentRestrictionList.md)
 - [PostStockNotationRankingIntradayListRequestDataMarket](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataMarket.md)
 - [PostStockNotationRankingIntradayListRequestDataMarketPriority](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataMarketPriority.md)
 - [PostStockNotationRankingIntradayListRequestDataNotationRestrictionList](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataNotationRestrictionList.md)
 - [PostStockNotationRankingIntradayListRequestDataPerformance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataPerformance.md)
 - [PostStockNotationRankingIntradayListRequestDataPerformanceRelative](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataPerformanceRelative.md)
 - [PostStockNotationRankingIntradayListRequestDataPerformanceRelativeMaximum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataPerformanceRelativeMaximum.md)
 - [PostStockNotationRankingIntradayListRequestDataPerformanceRelativeMinimum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataPerformanceRelativeMinimum.md)
 - [PostStockNotationRankingIntradayListRequestDataPrices](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestDataPrices.md)
 - [PostStockNotationRankingIntradayListRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestMeta.md)
 - [PostStockNotationRankingIntradayListRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationRankingIntradayListRequestMetaPagination.md)
 - [PostStockNotationScreenerSearchRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequest.md)
 - [PostStockNotationScreenerSearchRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestData.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmark](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmark.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBeta.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBetaMonth1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBetaMonth1.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBetaMonths3](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBetaMonths3.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBetaMonths6](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBetaMonths6.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBetaWeek1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBetaWeek1.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBetaYear1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBetaYear1.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBetaYears3](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBetaYears3.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkBetaYears5](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkBetaYears5.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkCorrelation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkCorrelation.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformance.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceMonth1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceMonth1.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceMonths3](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceMonths3.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceMonths6](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceMonths6.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceWeek1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceWeek1.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceYear1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceYear1.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceYears3](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceYears3.md)
 - [PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceYears5](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataBenchmarkOutperformanceYears5.md)
 - [PostStockNotationScreenerSearchRequestDataCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCompany.md)
 - [PostStockNotationScreenerSearchRequestDataCompanyCountry](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCompanyCountry.md)
 - [PostStockNotationScreenerSearchRequestDataCompanyCountryExclude](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCompanyCountryExclude.md)
 - [PostStockNotationScreenerSearchRequestDataCompanyCountryRestrict](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCompanyCountryRestrict.md)
 - [PostStockNotationScreenerSearchRequestDataCompliance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCompliance.md)
 - [PostStockNotationScreenerSearchRequestDataComplianceFrance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataComplianceFrance.md)
 - [PostStockNotationScreenerSearchRequestDataComplianceFranceAnd](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataComplianceFranceAnd.md)
 - [PostStockNotationScreenerSearchRequestDataComplianceFranceOr](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataComplianceFranceOr.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimates](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimates.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesCurrency.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesEbit.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesEbitMean](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesEbitMean.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesEbitda.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShare.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareDividends.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareEarnings.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentEstimatesPerShareSales.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFigures.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresCurrency.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresEbit.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresEbitda.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresMarketCapitalization](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresMarketCapitalization.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShare.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareBookValue.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareDividends](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareDividends.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareRecurringDilutedEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareRecurringDilutedEarnings.md)
 - [PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrencyDependentKeyFiguresPerShareSales.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFigures.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompany](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompany.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependent.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentCurrency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentCurrency.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentMarketCapitalizationSharesOutstanding](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentMarketCapitalizationSharesOutstanding.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShare.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareBookValue.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareEarnings.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyCurrencyDependentPerShareSales.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyFreeFloat](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanyFreeFloat.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanySharesOutstanding](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanySharesOutstanding.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanySharesOutstandingMaximum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanySharesOutstandingMaximum.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanySharesOutstandingMinimum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresCompanySharesOutstandingMinimum.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrument](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrument.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentCurrencyDependent](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentCurrencyDependent.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentCurrencyDependentPerShare](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentCurrencyDependentPerShare.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentCurrencyDependentPerShareDividend](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentCurrencyDependentPerShareDividend.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatios.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosDividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosDividendYield.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosEarningsYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosEarningsYield.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceBookValue.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceEarnings.md)
 - [PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataCurrentKeyFiguresShareInstrumentRatiosPriceSales.md)
 - [PostStockNotationScreenerSearchRequestDataEbitMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEbitMargin.md)
 - [PostStockNotationScreenerSearchRequestDataEbitMarginMaximum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEbitMarginMaximum.md)
 - [PostStockNotationScreenerSearchRequestDataEbitMarginMinimum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEbitMarginMinimum.md)
 - [PostStockNotationScreenerSearchRequestDataEbitdaMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEbitdaMargin.md)
 - [PostStockNotationScreenerSearchRequestDataEsg](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsg.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabs](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabs.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasb](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasb.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategories](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategories.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesInsight](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesInsight.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesInsightMaximum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesInsightMaximum.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesInsightMinimum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesInsightMinimum.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesMomentum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesMomentum.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesRanking](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbAllCategoriesRanking.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbMateriality](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSasbMateriality.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSdg](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSdg.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSdgImpact](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSdgImpact.md)
 - [PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSdgImpactMomentum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEsgTruvalueLabsSdgImpactMomentum.md)
 - [PostStockNotationScreenerSearchRequestDataEstimates](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataEstimates.md)
 - [PostStockNotationScreenerSearchRequestDataFiscalYear](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataFiscalYear.md)
 - [PostStockNotationScreenerSearchRequestDataFiscalYear1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataFiscalYear1.md)
 - [PostStockNotationScreenerSearchRequestDataGrossIncomeMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataGrossIncomeMargin.md)
 - [PostStockNotationScreenerSearchRequestDataIndexMembership](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataIndexMembership.md)
 - [PostStockNotationScreenerSearchRequestDataIndustryClassification](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataIndustryClassification.md)
 - [PostStockNotationScreenerSearchRequestDataIndustryClassificationExclude](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataIndustryClassificationExclude.md)
 - [PostStockNotationScreenerSearchRequestDataIndustryClassificationRestrict](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataIndustryClassificationRestrict.md)
 - [PostStockNotationScreenerSearchRequestDataNetIncomeMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataNetIncomeMargin.md)
 - [PostStockNotationScreenerSearchRequestDataOperatingMargin](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataOperatingMargin.md)
 - [PostStockNotationScreenerSearchRequestDataPerformance](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataPerformance.md)
 - [PostStockNotationScreenerSearchRequestDataPerformanceEndOfDay](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataPerformanceEndOfDay.md)
 - [PostStockNotationScreenerSearchRequestDataPerformanceEndOfDayDay1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataPerformanceEndOfDayDay1.md)
 - [PostStockNotationScreenerSearchRequestDataPerformanceEndOfDayYearToDate](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataPerformanceEndOfDayYearToDate.md)
 - [PostStockNotationScreenerSearchRequestDataPerformanceIntraday](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataPerformanceIntraday.md)
 - [PostStockNotationScreenerSearchRequestDataRatios](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1DividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1DividendYield.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1EnterpriseValueEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1EnterpriseValueEbit.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1EnterpriseValueEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1EnterpriseValueEbitda.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1EnterpriseValueSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1EnterpriseValueSales.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1PriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1PriceBookValue.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1PriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1PriceCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1PriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1PriceEarnings.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1PriceEarningsGrowth](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1PriceEarningsGrowth.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1PriceEarningsGrowthMean](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1PriceEarningsGrowthMean.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1PriceFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1PriceFreeCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataRatios1PriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatios1PriceSales.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosDebtEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosDebtEquity.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosDividendYield](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosDividendYield.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosEnterpriseValueEbit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosEnterpriseValueEbit.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosEnterpriseValueEbitda](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosEnterpriseValueEbitda.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosEnterpriseValueSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosEnterpriseValueSales.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosPriceBookValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosPriceBookValue.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosPriceCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosPriceCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosPriceEarnings](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosPriceEarnings.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosPriceFreeCashFlow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosPriceFreeCashFlow.md)
 - [PostStockNotationScreenerSearchRequestDataRatiosPriceSales](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRatiosPriceSales.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendation.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendationConsensus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendationConsensus.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendationConsensusChange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendationConsensusChange.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendationConsensusRange](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendationConsensusRange.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendationCounts](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendationCounts.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendationCountsTotal](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendationCountsTotal.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendationCountsTotalMaximum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendationCountsTotalMaximum.md)
 - [PostStockNotationScreenerSearchRequestDataRecommendationCountsTotalMinimum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRecommendationCountsTotalMinimum.md)
 - [PostStockNotationScreenerSearchRequestDataReportedKeyFigures](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataReportedKeyFigures.md)
 - [PostStockNotationScreenerSearchRequestDataReturnOnAssets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataReturnOnAssets.md)
 - [PostStockNotationScreenerSearchRequestDataReturnOnAssets1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataReturnOnAssets1.md)
 - [PostStockNotationScreenerSearchRequestDataReturnOnAssets1Mean](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataReturnOnAssets1Mean.md)
 - [PostStockNotationScreenerSearchRequestDataReturnOnEquity](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataReturnOnEquity.md)
 - [PostStockNotationScreenerSearchRequestDataReturnOnEquity1](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataReturnOnEquity1.md)
 - [PostStockNotationScreenerSearchRequestDataRsiWilder](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRsiWilder.md)
 - [PostStockNotationScreenerSearchRequestDataRsiWilderDays14](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataRsiWilderDays14.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverage.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageDays20](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageDays20.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageDays200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageDays200.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageDays50](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageDays50.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossover](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossover.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50NumberDays](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50NumberDays.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50NumberDaysMaximum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50NumberDaysMaximum.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50NumberDaysMinimum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma20vs50NumberDaysMinimum.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200NumberDays](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200NumberDays.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200NumberDaysMaximum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200NumberDaysMaximum.md)
 - [PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200NumberDaysMinimum](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataSimpleMovingAverageTradingDaysSinceCrossoverSma50vs200NumberDaysMinimum.md)
 - [PostStockNotationScreenerSearchRequestDataTradingValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataTradingValue.md)
 - [PostStockNotationScreenerSearchRequestDataTradingValueAverage](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataTradingValueAverage.md)
 - [PostStockNotationScreenerSearchRequestDataTradingValueAverageDays30](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataTradingValueAverageDays30.md)
 - [PostStockNotationScreenerSearchRequestDataTradingValueAverageDays5](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataTradingValueAverageDays5.md)
 - [PostStockNotationScreenerSearchRequestDataValidation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidation.md)
 - [PostStockNotationScreenerSearchRequestDataValidationInstrumentSelectionList](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationInstrumentSelectionList.md)
 - [PostStockNotationScreenerSearchRequestDataValidationInstrumentSelectionListExclude](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationInstrumentSelectionListExclude.md)
 - [PostStockNotationScreenerSearchRequestDataValidationInstrumentSelectionListRestrict](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationInstrumentSelectionListRestrict.md)
 - [PostStockNotationScreenerSearchRequestDataValidationMarket](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationMarket.md)
 - [PostStockNotationScreenerSearchRequestDataValidationMarketPriority](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationMarketPriority.md)
 - [PostStockNotationScreenerSearchRequestDataValidationMarketSelection](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationMarketSelection.md)
 - [PostStockNotationScreenerSearchRequestDataValidationMarketSelectionExclude](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationMarketSelectionExclude.md)
 - [PostStockNotationScreenerSearchRequestDataValidationMarketSelectionRestrict](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationMarketSelectionRestrict.md)
 - [PostStockNotationScreenerSearchRequestDataValidationNotationSelectionList](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationNotationSelectionList.md)
 - [PostStockNotationScreenerSearchRequestDataValidationNotationSelectionListExclude](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationNotationSelectionListExclude.md)
 - [PostStockNotationScreenerSearchRequestDataValidationNotationSelectionListRestrict](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationNotationSelectionListRestrict.md)
 - [PostStockNotationScreenerSearchRequestDataValidationPrices](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationPrices.md)
 - [PostStockNotationScreenerSearchRequestDataValidationPricesLatest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationPricesLatest.md)
 - [PostStockNotationScreenerSearchRequestDataValidationPricesPrevious](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationPricesPrevious.md)
 - [PostStockNotationScreenerSearchRequestDataValidationValueUnit](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationValueUnit.md)
 - [PostStockNotationScreenerSearchRequestDataValidationValueUnitExclude](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationValueUnitExclude.md)
 - [PostStockNotationScreenerSearchRequestDataValidationValueUnitRestrict](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataValidationValueUnitRestrict.md)
 - [PostStockNotationScreenerSearchRequestDataVolatility](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestDataVolatility.md)
 - [PostStockNotationScreenerSearchRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestMeta.md)
 - [PostStockNotationScreenerSearchRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerSearchRequestMetaPagination.md)
 - [PostStockNotationScreenerValueRangesGetRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerValueRangesGetRequest.md)
 - [PostStockNotationScreenerValueRangesGetRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerValueRangesGetRequestData.md)
 - [PostStockNotationScreenerValueRangesGetRequestDataRecommendation](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerValueRangesGetRequestDataRecommendation.md)
 - [PostStockNotationScreenerValueRangesGetRequestDataRecommendationConsensus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/PostStockNotationScreenerValueRangesGetRequestDataRecommendationConsensus.md)
 - [StatusObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/StocksAPIforDigitalPortals/v3/docs/StatusObject.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.StocksAPIforDigitalPortals.apis and fds.sdk.StocksAPIforDigitalPortals.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.StocksAPIforDigitalPortals.api.default_api import DefaultApi`
- `from fds.sdk.StocksAPIforDigitalPortals.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.StocksAPIforDigitalPortals
from fds.sdk.StocksAPIforDigitalPortals.apis import *
from fds.sdk.StocksAPIforDigitalPortals.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

